==> estateplat-common-1.1.0-20160803.085537-138-sources.jar: cn/gtmap/estateplat/model/server/core/GdTdsyq.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;
import java.util.Date;

/**
 * 土地所有权
 *
 * @author lst
 * @version V1.0, 15-5-9
 */
@Table(name = "GD_TDSYQ")
public class GdTdsyq implements Serializable {
    @Id
    private String qlid;
    private String tdzh;
    private String tdid;
    private Integer iszx;
    private String djlx;
    private String djyy;
    private String fwid;
    private String proid;
    private Double dymj;
    private Double ftmj;
    private Double tdzmj;
    private Double nyd;
    private Double gd;
    private Double yd;
    private Double ld;

    private Double mcd;
    private Double qtnyd;
    private Double jsyd;
    private Double wlyd;
    private String issynq;//是否是使用权
    private String cjrid;
    private String yqzh;
    private String fj;
    private String bz;//备注
    private String sffgw;//是否分割完,0不是,1是



    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @version 1.0, 2016/8/3
     * @description 档案业务号，用于挂接过渡土地登记数据的档案材料信息
     */
    private String daywh;

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    private Date lzrq;//领证日期

    public Double getTdzmj() {
        return tdzmj;
    }

    public void setTdzmj(Double tdzmj) {
        this.tdzmj = tdzmj;
    }

    public Double getNyd() {
        return nyd;
    }

    public void setNyd(Double nyd) {
        this.nyd = nyd;
    }

    public Double getGd() {
        return gd;
    }

    public void setGd(Double gd) {
        this.gd = gd;
    }

    public Double getYd() {
        return yd;
    }

    public void setYd(Double yd) {
        this.yd = yd;
    }

    public Double getLd() {
        return ld;
    }

    public void setLd(Double ld) {
        this.ld = ld;
    }

    public Double getMcd() {
        return mcd;
    }

    public void setMcd(Double mcd) {
        this.mcd = mcd;
    }

    public Double getQtnyd() {
        return qtnyd;
    }

    public void setQtnyd(Double qtnyd) {
        this.qtnyd = qtnyd;
    }

    public Double getJsyd() {
        return jsyd;
    }

    public void setJsyd(Double jsyd) {
        this.jsyd = jsyd;
    }

    public Double getWlyd() {
        return wlyd;
    }

    public void setWlyd(Double wlyd) {
        this.wlyd = wlyd;
    }

    public String getCjrid() {
        return cjrid;
    }

    public void setCjrid(String cjrid) {
        this.cjrid = cjrid;
    }

    public String getYqzh() {
        return yqzh;
    }

    public void setYqzh(String yqzh) {
        this.yqzh = yqzh;
    }

    public String getQlid() {
        return qlid;
    }

    public void setQlid(String qlid) {
        this.qlid = qlid;
    }

    public String getTdzh() {
        return tdzh;
    }

    public void setTdzh(String tdzh) {
        this.tdzh = tdzh;
    }

    public String getTdid() {
        return tdid;
    }

    public void setTdid(String tdid) {
        this.tdid = tdid;
    }

    public Integer getIszx() {
        return iszx;
    }

    public void setIszx(Integer iszx) {
        this.iszx = iszx;
    }

    public String getDjlx() {
        return djlx;
    }

    public void setDjlx(String djlx) {
        this.djlx = djlx;
    }

    public String getDjyy() {
        return djyy;
    }

    public void setDjyy(String djyy) {
        this.djyy = djyy;
    }

    public String getFwid() {
        return fwid;
    }

    public void setFwid(String fwid) {
        this.fwid = fwid;
    }

    public String getProid() {
        return proid;
    }

    public void setProid(String proid) {
        this.proid = proid;
    }

    public Double getDymj() {
        return dymj;
    }

    public void setDymj(Double dymj) {
        this.dymj = dymj;
    }

    public Double getFtmj() {
        return ftmj;
    }

    public void setFtmj(Double ftmj) {
        this.ftmj = ftmj;
    }

    public String getIssynq() {
        return issynq;
    }

    public void setIssynq(String issynq) {
        this.issynq = issynq;
    }

    public Date getLzrq() {
        return lzrq;
    }

    public void setLzrq(Date lzrq) {
        this.lzrq = lzrq;
    }

    public String getFj() {
        return fj;
    }

    public void setFj(String fj) {
        this.fj = fj;
    }

    public String getSffgw() {
        return sffgw;
    }

    public void setSffgw(String sffgw) {
        this.sffgw = sffgw;
    }

    public String getDaywh() {
        return daywh;
    }

    public void setDaywh(String daywh) {
        this.daywh = daywh;
    }
}

==> estateplat-common-1.1.0-20160803.133405-139-sources.jar: cn/gtmap/estateplat/model/server/core/GdTdsyq.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;
import java.util.Date;

/**
 * 土地所有权
 *
 * @author lst
 * @version V1.0, 15-5-9
 */
@Table(name = "GD_TDSYQ")
public class GdTdsyq implements Serializable {
    @Id
    private String qlid;
    private String tdzh;
    private String tdid;
    private Integer iszx;
    private String djlx;
    private String djyy;
    private String fwid;
    private String proid;
    private Double dymj;
    private Double ftmj;
    private Double tdzmj;
    private Double nyd;
    private Double gd;
    private Double yd;
    private Double ld;

    private Double mcd;
    private Double qtnyd;
    private Double jsyd;
    private Double wlyd;
    private String issynq;//是否是使用权
    private String cjrid;
    private String yqzh;
    private String fj;
    private String bz;//备注
    private String sffgw;//是否分割完,0不是,1是
    private Date djsj;//登记时间
    private String dbr;//登薄人



    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @version 1.0, 2016/8/3
     * @description 档案业务号，用于挂接过渡土地登记数据的档案材料信息
     */
    private String daywh;

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    private Date lzrq;//领证日期

    public Double getTdzmj() {
        return tdzmj;
    }

    public void setTdzmj(Double tdzmj) {
        this.tdzmj = tdzmj;
    }

    public Double getNyd() {
        return nyd;
    }

    public void setNyd(Double nyd) {
        this.nyd = nyd;
    }

    public Double getGd() {
        return gd;
    }

    public void setGd(Double gd) {
        this.gd = gd;
    }

    public Double getYd() {
        return yd;
    }

    public void setYd(Double yd) {
        this.yd = yd;
    }

    public Double getLd() {
        return ld;
    }

    public void setLd(Double ld) {
        this.ld = ld;
    }

    public Double getMcd() {
        return mcd;
    }

    public void setMcd(Double mcd) {
        this.mcd = mcd;
    }

    public Double getQtnyd() {
        return qtnyd;
    }

    public void setQtnyd(Double qtnyd) {
        this.qtnyd = qtnyd;
    }

    public Double getJsyd() {
        return jsyd;
    }

    public void setJsyd(Double jsyd) {
        this.jsyd = jsyd;
    }

    public Double getWlyd() {
        return wlyd;
    }

    public void setWlyd(Double wlyd) {
        this.wlyd = wlyd;
    }

    public String getCjrid() {
        return cjrid;
    }

    public void setCjrid(String cjrid) {
        this.cjrid = cjrid;
    }

    public String getYqzh() {
        return yqzh;
    }

    public void setYqzh(String yqzh) {
        this.yqzh = yqzh;
    }

    public String getQlid() {
        return qlid;
    }

    public void setQlid(String qlid) {
        this.qlid = qlid;
    }

    public String getTdzh() {
        return tdzh;
    }

    public void setTdzh(String tdzh) {
        this.tdzh = tdzh;
    }

    public String getTdid() {
        return tdid;
    }

    public void setTdid(String tdid) {
        this.tdid = tdid;
    }

    public Integer getIszx() {
        return iszx;
    }

    public void setIszx(Integer iszx) {
        this.iszx = iszx;
    }

    public String getDjlx() {
        return djlx;
    }

    public void setDjlx(String djlx) {
        this.djlx = djlx;
    }

    public String getDjyy() {
        return djyy;
    }

    public void setDjyy(String djyy) {
        this.djyy = djyy;
    }

    public String getFwid() {
        return fwid;
    }

    public void setFwid(String fwid) {
        this.fwid = fwid;
    }

    public String getProid() {
        return proid;
    }

    public void setProid(String proid) {
        this.proid = proid;
    }

    public Double getDymj() {
        return dymj;
    }

    public void setDymj(Double dymj) {
        this.dymj = dymj;
    }

    public Double getFtmj() {
        return ftmj;
    }

    public void setFtmj(Double ftmj) {
        this.ftmj = ftmj;
    }

    public String getIssynq() {
        return issynq;
    }

    public void setIssynq(String issynq) {
        this.issynq = issynq;
    }

    public Date getLzrq() {
        return lzrq;
    }

    public void setLzrq(Date lzrq) {
        this.lzrq = lzrq;
    }

    public String getFj() {
        return fj;
    }

    public void setFj(String fj) {
        this.fj = fj;
    }

    public String getSffgw() {
        return sffgw;
    }

    public void setSffgw(String sffgw) {
        this.sffgw = sffgw;
    }

    public String getDaywh() {
        return daywh;
    }

    public void setDaywh(String daywh) {
        this.daywh = daywh;
    }

    public Date getDjsj() {
        return djsj;
    }

    public void setDjsj(Date djsj) {
        this.djsj = djsj;
    }

    public String getDbr() {
        return dbr;
    }

    public void setDbr(String dbr) {
        this.dbr = dbr;
    }
}
